==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/RelationshipCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Relationship;
import microsoft.dynamics.crm.entity.request.RelationshipRequest;
import microsoft.dynamics.crm.entity.request.RelationshipattributeRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class RelationshipCollectionRequest extends CollectionPageEntityRequest<Relationship, RelationshipRequest>{

    protected ContextPath contextPath;

    public RelationshipCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Relationship.class, cp -> new RelationshipRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public RelationshipattributeCollectionRequest relationship_relationshipattribute() {
        return new RelationshipattributeCollectionRequest(contextPath.addSegment("relationship_relationshipattribute"), Optional.empty());
    }

    public RelationshipattributeRequest relationship_relationshipattribute(String relationshipattributeid) {
        return new RelationshipattributeRequest(contextPath.addSegment("relationship_relationshipattribute").addKeys(new NameValue(relationshipattributeid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/RelationshipCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Relationship;
import microsoft.dynamics.crm.entity.request.RelationshipRequest;
import microsoft.dynamics.crm.entity.request.RelationshipattributeRequest;

public class RelationshipCollectionRequest extends CollectionPageEntityRequest<Relationship, RelationshipRequest>{

    protected ContextPath contextPath;

    public RelationshipCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Relationship.class, cp -> new RelationshipRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public RelationshipattributeCollectionRequest relationship_relationshipattribute() {
        return new RelationshipattributeCollectionRequest(contextPath.addSegment("relationship_relationshipattribute"), Optional.empty());
    }

    public RelationshipattributeRequest relationship_relationshipattribute(String relationshipattributeid) {
        return new RelationshipattributeRequest(contextPath.addSegment("relationship_relationshipattribute").addKeys(new NameValue(relationshipattributeid.toString())), Optional.empty());
    }

}
